@@ -327,7 +327,9 @@ Allow: /2heavy/*.html
       robots.reset(url)
 
       assert robots.allowed?(url)
-      assert_instance_of WebRobots::ParseError, robots.error(url)
+      error = robots.error(url)
+      assert_instance_of WebRobots::ParseError, error
+      assert_equal URI('http://www.example.org/'), error.site
       assert_raise(WebRobots::ParseError) {
         robots.error!(url)
       }
@@ -472,6 +474,7 @@ Disallow: /
     should "be parsed for major sites" do
       assert_nothing_raised {
         assert !@testbot.allowed?("http://www.google.com/search")
+        assert !@testbot.allowed?("https://www.google.com/search")
         assert !@testbot.allowed?("http://www.google.com/news/section?pz=1&cf=all&ned=jp&topic=y&ict=ln")
         assert @testbot.allowed?("http://www.google.com/news/directory?pz=1&cf=all&ned=us&hl=en&sort=users&category=6")
       }
@@ -655,4 +658,25 @@ TXT
       assert !@fetched
     end
   end
+
+  context "robots.txt with just user-agent & sitemap and no blank line between them" do
+    setup do
+      @robots = WebRobots.new('RandomBot', :http_get => lambda { |uri|
+        res = case uri.to_s
+          when 'http://site1.example.com/robots.txt'
+          <<-'TXT'
+User-agent: *
+Sitemap: http://site1.example.com/text/sitemap.xml
+TXT
+        else
+          raise "#{uri} is not supposed to be fetched"
+        end
+      })
+    end
+
+    should "be properly parsed" do
+      assert @robots.allowed?("http://site1.example.com/foo")
+      assert_equal(["http://site1.example.com/text/sitemap.xml"], @robots.sitemaps("http://site1.example.com/"))
+    end
+  end
 end
